@@ -208,6 +208,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Scrapy",
     "Framework :: Setuptools Plugin",
     "Framework :: Sphinx",
+    "Framework :: Sphinx :: Domain",
     "Framework :: Sphinx :: Extension",
     "Framework :: Sphinx :: Theme",
     "Framework :: Trac",
@@ -223,6 +224,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Wagtail :: 3",
     "Framework :: Wagtail :: 4",
     "Framework :: Wagtail :: 5",
+    "Framework :: Wagtail :: 6",
     "Framework :: ZODB",
     "Framework :: Zope",
     "Framework :: Zope2",
@@ -328,6 +330,7 @@ sorted_classifiers: List[str] = [
     "License :: OSI Approved :: Vovida Software License 1.0",
     "License :: OSI Approved :: W3C License",
     "License :: OSI Approved :: X.Net License",
+    "License :: OSI Approved :: Zero-Clause BSD (0BSD)",
     "License :: OSI Approved :: Zope Public License",
     "License :: OSI Approved :: zlib/libpng License",
     "License :: Other/Proprietary License",
@@ -729,6 +732,9 @@ sorted_classifiers: List[str] = [
     "Topic :: Software Development :: Disassemblers",
     "Topic :: Software Development :: Documentation",
     "Topic :: Software Development :: Embedded Systems",
+    "Topic :: Software Development :: Embedded Systems :: Controller Area Network (CAN)",
+    "Topic :: Software Development :: Embedded Systems :: Controller Area Network (CAN) :: CANopen",
+    "Topic :: Software Development :: Embedded Systems :: Controller Area Network (CAN) :: J1939",
     "Topic :: Software Development :: Internationalization",
     "Topic :: Software Development :: Interpreters",
     "Topic :: Software Development :: Libraries",
